scipy.sparse.spfuncs
====================

.. automodule:: scipy.sparse.spfuncs

   
   
   .. rubric:: Functions

   .. autosummary::
   
      count_blocks
      csr_count_blocks
      estimate_blocksize
      extract_diagonal
      isspmatrix_csc
      isspmatrix_csr
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      csr_matrix
   
   

   
   
   